@@ -1,14 +1,15 @@
 import logging
 from contextlib import asynccontextmanager
-from typing import AsyncIterable
+from typing import AsyncIterator, Union
 
 from aioch import Client
 from clickhouse_driver import errors
 
 from tesseract_olap.backend import Backend
 from tesseract_olap.backend.exceptions import UpstreamInternalError
-from tesseract_olap.common import AnyDict
+from tesseract_olap.common import AnyTuple
 from tesseract_olap.query import DataQuery, MembersQuery
+from tesseract_olap.query.exceptions import InvalidQuery
 from tesseract_olap.schema import Schema
 
 from .sqlbuild import dataquery_sql, membersquery_sql
@@ -45,7 +46,7 @@ class ClickhouseBackend(Backend):
         finally:
             await client.disconnect()
 
-    async def connect(self):
+    async def connect(self, **kwargs):
         pass
 
     def close(self):
@@ -54,48 +55,42 @@ class ClickhouseBackend(Backend):
     async def wait_closed(self):
         pass
 
-    async def get_data(self, query: "DataQuery", **kwargs) -> AsyncIterable[AnyDict]:
-        """Retrieves the dataset for the request made by the :class:`DataQuery`
-        instance, from the database.
+    async def execute(
+        self,
+        query: Union["DataQuery", "MembersQuery"],
+        **kwargs
+    ) -> AsyncIterator[AnyTuple]:
         """
-        logger.debug("%r", query)
-
-        sql_builder, sql_params = dataquery_sql(query)
-        sql_query = sql_builder.get_sql()
-        logger.debug("%s\n%s", sql_query, sql_params)
-
-        async with self._acquire() as client:
-            result = await client.execute_iter(query=sql_query,
-                                               params=sql_params,
-                                               settings={'max_block_size': 5000},
-                                               with_column_types=True)
-            columns, _ = zip(*(await result.__anext__()))
-            async for row in result:
-                yield dict(zip(columns, row))
-
-    async def get_members(self, query: "MembersQuery", **kwargs):
-        """Retrieves the members for the request made by the :class:`MembersQuery`
-        instance, from the database.
+        Processes the requests in a :class:`DataQuery` or :class:`MembersQuery`
+        instance, sends the query to the database, and returns an `AsyncIterator`
+        to access the rows.
+        Each iteration yields a tuple of the same length, where the first tuple
+        defines the column names, and the subsequents are rows with the data in
+        the same order as each column.
         """
-        logger.debug("%r", query)
+        logger.debug("Execute query", extra={"query": query})
 
-        sql_builder, sql_params = membersquery_sql(query)
-        sql_query = sql_builder.get_sql()
-        logger.debug(sql_query, sql_params)
+        if isinstance(query, MembersQuery):
+            sql_builder, sql_params = membersquery_sql(query)
+        elif isinstance(query, DataQuery):
+            sql_builder, sql_params = dataquery_sql(query)
+        else:
+            raise InvalidQuery(
+                "ClickhouseBackend only supports DataQuery and MembersQuery instances"
+            )
 
-        async with self._acquire() as client:
-            result = await client.execute_iter(query=sql_query,
+        async with self._acquire() as cursor:
+            result = await cursor.execute_iter(query=sql_builder.get_sql(),
                                                params=sql_params,
-                                               settings={'max_block_size': 5000},
+                                               settings={"max_block_size": 5000},
                                                with_column_types=True)
-            columns, _ = zip(*(await result.__anext__()))
             async for row in result:
-                yield dict(zip(columns, row))
+                yield row
 
     async def ping(self) -> bool:
         """Checks if the current connection is working correctly."""
-        async with self._acquire() as client:
-            result = await client.execute("SELECT 1")
+        async with self._acquire() as cursor:
+            result = await cursor.execute("SELECT 1")
             return result == [(1,)]
 
     async def validate_schema(self, schema: "Schema") -> None:
