@@ -8,9 +8,9 @@ backend class that adapts the Query and the Results to the defined interface.
 import abc
 import uuid
 from dataclasses import dataclass, field
-from typing import TYPE_CHECKING, AsyncIterable, Dict, Optional
+from typing import TYPE_CHECKING, AsyncIterator, Dict, Optional, Union
 
-from tesseract_olap.common.types import AnyDict
+from tesseract_olap.common import AnyTuple
 
 if TYPE_CHECKING:
     from tesseract_olap.query import DataQuery, MembersQuery
@@ -27,6 +27,7 @@ class Backend(abc.ABC):
     @abc.abstractmethod
     async def connect(self, **kwargs):
         """Establishes the connection to the backend server.
+
         This operation must be done before running any other data method, and
         must be separate from the creation of a :class:`Backend` instance.
         """
@@ -36,6 +37,7 @@ class Backend(abc.ABC):
     def close(self):
         """Performs the needed operations to safely close the connection with
         the backend server.
+
         This method is synchronous for compatibility with the signature of other
         `close()` calls, but since closing operations are asynchronous, the
         closing procedure must be combined with the `wait_closed()` method, and
@@ -50,17 +52,17 @@ class Backend(abc.ABC):
         raise NotImplementedError()
 
     @abc.abstractmethod
-    def get_data(self, query: "DataQuery", **kwargs) -> AsyncIterable[AnyDict]:
-        """Sends the :class:`DataQuery` instance to the backend server for
-        retrieval of the intended data.
-        """
-        raise NotImplementedError()
-
-    @abc.abstractmethod
-    def get_members(self, query: "MembersQuery", **kwargs) -> AsyncIterable[AnyDict]:
-        """Obtains a list of the members for a level, and its related properties.
+    async def execute(
+        self,
+        query: Union["DataQuery", "MembersQuery"],
+        **kwargs
+    ) -> AsyncIterator[AnyTuple]:
+        """Processes the requests in a :class:`DataQuery` or :class:`MembersQuery`
+        instance, sends the query to the database, and returns an `AsyncIterator`
+        to access the rows.
         """
         raise NotImplementedError()
+        yield tuple() # pylance thinks it's a coroutine without this
 
     @abc.abstractmethod
     async def ping(self) -> bool:
