@@ -6,13 +6,11 @@ for use with a :class:`LogicLayer` instance.
 
 import dataclasses
 from pathlib import Path
-from typing import Any, Optional, Union
+from typing import Optional, Union
 
 import logiclayer as ll
-import orjson
 from fastapi import Depends, HTTPException, Request
-from fastapi.encoders import jsonable_encoder
-from fastapi.responses import FileResponse, RedirectResponse, StreamingResponse
+from fastapi.responses import FileResponse, RedirectResponse
 
 from tesseract_olap import __version__ as tesseract_version
 from tesseract_olap.backend.exceptions import BackendError
@@ -21,6 +19,7 @@ from tesseract_olap.query.exceptions import QueryError
 from tesseract_olap.server import OlapServer
 
 from .dependencies import dataquery_params, membersquery_params
+from .response import StreamingJSONResponse
 
 
 class TesseractModule(ll.LogicLayerModule):
@@ -93,15 +92,16 @@ class TesseractModule(ll.LogicLayerModule):
         query: DataRequest = Depends(dataquery_params),
     ):
         try:
-            result = await self.server.get_data(query)
+            result = await self.server.execute(query)
         except QueryError as exc:
             raise HTTPException(status_code=400, detail=exc.message) from None
         except BackendError as exc:
             raise HTTPException(status_code=500, detail=exc.message) from None
-        return StreamingResponse(result_to_asyncgen(result.data, {
+        return StreamingJSONResponse({
+            "data": result.data_tidy(),
             "format": filetype,
             "sources": result.sources,
-        }))
+        })
 
     @ll.route("GET", "/members.{filetype}")
     async def query_members(
@@ -110,14 +110,15 @@ class TesseractModule(ll.LogicLayerModule):
         query: MembersRequest = Depends(membersquery_params),
     ):
         try:
-            result = await self.server.get_members(query)
+            result = await self.server.execute(query)
         except QueryError as exc:
             raise HTTPException(status_code=400, detail=exc.message) from None
         except BackendError as exc:
             raise HTTPException(status_code=500, detail=exc.message) from None
-        return StreamingResponse(result_to_asyncgen(result.data, {
+        return StreamingJSONResponse({
+            "data": result.data_tidy(),
             "format": filetype,
-        }))
+        })
 
     @ll.route("GET", "/debug/schema", debug=True)
     def debug_schema(self):
@@ -140,15 +141,3 @@ class TesseractModule(ll.LogicLayerModule):
         with filepath.open("w", encoding="utf-8") as fileio:
             fileio.write("")
         return
-
-
-async def result_to_asyncgen(data: Any, extra: dict):
-    yield orjson.dumps(extra, default=jsonable_encoder)[:-1]
-    yield b',"data":['
-    comma = ''
-    async for row in data:
-        yield comma
-        comma = b','
-        yield orjson.dumps(row)
-    yield b']}'
-
