@@ -6,8 +6,10 @@ modules.
 
 import dataclasses
 from hashlib import md5
-from typing import (Dict, FrozenSet, Iterable, Literal, NamedTuple, Optional,
-                    Set, Tuple, Union)
+from typing import (Dict, FrozenSet, Iterable, NamedTuple, Optional, Set,
+                    Tuple, Union)
+
+from typing_extensions import Literal
 
 from tesseract_olap.common import Array, Prim
 from tesseract_olap.schema import (DimensionTraverser, HierarchyTraverser,
