@@ -4,12 +4,12 @@ from itertools import chain
 from typing import (Generic, Iterable, Iterator, List, Mapping, Optional,
                     OrderedDict, Set, TypeVar, Union)
 
-from tesseract_olap.common.captions import get_localization
+from tesseract_olap.common import get_localization
 from tesseract_olap.query.exceptions import (InvalidEntityName,
                                              TimeDimensionUnavailable,
                                              TimeScaleUnavailable)
 
-from .enums import DimensionType
+from .enums import DimensionType, MemberType
 from .exceptions import DuplicatedNameError, MissingPropertyError
 from .models import (Annotations, CaptionSet, Cube, Dimension, DimensionUsage,
                      Entity, Hierarchy, HierarchyUsage, InlineTable, Level,
@@ -313,7 +313,6 @@ class EntityUsageTraverser(Generic[EntityType, UsageType]):
         return sorted(set(dir(self._entity) + dir(self)))
 
     def __getattr__(self, name: str):
-        logger.debug("__getattr__ call for %s on %r", name, self)
         return getattr(self._entity, name)
 
     def __repr__(self) -> str:
@@ -527,6 +526,7 @@ class LevelTraverser(EntityUsageTraverser[Level, LevelUsage]):
     """
     depth: int
     key_column: str
+    key_type: MemberType
     property_map: Mapping[str, "PropertyTraverser"]
 
     def __init__(self,
